==> kubernetes-model-1.0.56-sources.jar: io/fabric8/kubernetes/api/model/OwnerReferenceBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import java.util.Set;
import java.lang.Object;

public class OwnerReferenceBuilder extends OwnerReferenceFluentImpl<OwnerReferenceBuilder> implements VisitableBuilder<OwnerReference,OwnerReferenceBuilder>{

    OwnerReferenceFluent<?> fluent;
    Boolean validationEnabled;

    public OwnerReferenceBuilder(){
            this(true);
    }
    public OwnerReferenceBuilder(Boolean validationEnabled){
            this(new OwnerReference(), validationEnabled);
    }
    public OwnerReferenceBuilder(OwnerReferenceFluent<?> fluent){
            this(fluent, true);
    }
    public OwnerReferenceBuilder(OwnerReferenceFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new OwnerReference(), validationEnabled);
    }
    public OwnerReferenceBuilder(OwnerReferenceFluent<?> fluent,OwnerReference instance){
            this(fluent, instance, true);
    }
    public OwnerReferenceBuilder(OwnerReferenceFluent<?> fluent,OwnerReference instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withApiVersion(instance.getApiVersion()); 
            fluent.withController(instance.getController()); 
            fluent.withKind(instance.getKind()); 
            fluent.withName(instance.getName()); 
            fluent.withUid(instance.getUid()); 
            this.validationEnabled = validationEnabled; 
    }
    public OwnerReferenceBuilder(OwnerReference instance){
            this(instance,true);
    }
    public OwnerReferenceBuilder(OwnerReference instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withApiVersion(instance.getApiVersion()); 
            this.withController(instance.getController()); 
            this.withKind(instance.getKind()); 
            this.withName(instance.getName()); 
            this.withUid(instance.getUid()); 
            this.validationEnabled = validationEnabled; 
    }

    public OwnerReference build(){
            OwnerReference buildable = new OwnerReference(fluent.getApiVersion(),fluent.isController(),fluent.getKind(),fluent.getName(),fluent.getUid());
            validate(buildable);
            return buildable;
    }

    private <T>void validate(T item){
            if (!validationEnabled) { return; }
            Validator validator = null;
            try {
                ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
                validator = factory.getValidator();
            } catch(ValidationException e) {return;}
            Set<ConstraintViolation<T>> violations = validator.validate(item);
            if (!violations.isEmpty()) {
            throw new ConstraintViolationException(violations);
             }
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            OwnerReferenceBuilder that = (OwnerReferenceBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}

==> kubernetes-model-1.0.64-sources.jar: io/fabric8/kubernetes/api/model/OwnerReferenceBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import javax.annotation.Generated;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import java.lang.Object;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.lang.Boolean;
import lombok.ToString;
import io.sundr.builder.annotations.Buildable;

public class OwnerReferenceBuilder extends OwnerReferenceFluentImpl<OwnerReferenceBuilder> implements VisitableBuilder<OwnerReference,OwnerReferenceBuilder>{

    OwnerReferenceFluent<?> fluent;
    Boolean validationEnabled;

    public OwnerReferenceBuilder(){
            this(true);
    }
    public OwnerReferenceBuilder(Boolean validationEnabled){
            this(new OwnerReference(), validationEnabled);
    }
    public OwnerReferenceBuilder(OwnerReferenceFluent<?> fluent){
            this(fluent, true);
    }
    public OwnerReferenceBuilder(OwnerReferenceFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new OwnerReference(), validationEnabled);
    }
    public OwnerReferenceBuilder(OwnerReferenceFluent<?> fluent,OwnerReference instance){
            this(fluent, instance, true);
    }
    public OwnerReferenceBuilder(OwnerReferenceFluent<?> fluent,OwnerReference instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withApiVersion(instance.getApiVersion()); 
            fluent.withController(instance.getController()); 
            fluent.withKind(instance.getKind()); 
            fluent.withName(instance.getName()); 
            fluent.withUid(instance.getUid()); 
            this.validationEnabled = validationEnabled; 
    }
    public OwnerReferenceBuilder(OwnerReference instance){
            this(instance,true);
    }
    public OwnerReferenceBuilder(OwnerReference instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withApiVersion(instance.getApiVersion()); 
            this.withController(instance.getController()); 
            this.withKind(instance.getKind()); 
            this.withName(instance.getName()); 
            this.withUid(instance.getUid()); 
            this.validationEnabled = validationEnabled; 
    }

    public OwnerReference build(){
            OwnerReference buildable = new OwnerReference(fluent.getApiVersion(),fluent.isController(),fluent.getKind(),fluent.getName(),fluent.getUid());
            io.fabric8.kubernetes.api.builder.ValidationUtils.validate(buildable);
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            OwnerReferenceBuilder that = (OwnerReferenceBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}
